---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Environment (please complete the following information):**
 - Version [e.g. 1.2.6]
 - OS: [e.g. Ubuntu 22.04]

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Basic trade parameters:
- exchange:
- pair:
- other:

Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.
